EDICTOR

- Files are loading, please wait...

  Open the file.
- EDICTOR

  ### Settings

  Preview |
  Cognate IDs |
  Partial Cognates |
  Tokens |
  Alignments |
  Morphology and Colexification Mode | FULL PARTIAL
  Computation Mode | LingPy / LingRex EDICTOR
  Morphemes |
  Patterns |
  Sources |
  Phonetic Entries |
  X-SAMPA |
  Doculect Order |
  SOURCE |
  NOTE |
  PROTO |

- Welcome to EDICTOR 3!
  EDICTOR 3 is an interactive tool for creating, maintaining, and publishing etymological data which is stored in simple TSV format.
  Use the EDICTOR to
  - create your datasets from scratch,
  - annotate your existing datasets,
  - identify and annotate cognates,
  - create alignments,
  - annotate language-internal cognates,
  - check your data, and
  - carry out various kinds of analyses.
  In order to get started with an existing example dataset, just click this link. Press here to learn more ABOUT the EDICTOR, or here to get further HELP. If you use the EDICTOR in your work, please cite the paper by List (2017) which can be downloaded here. You can also cite the actual version of the EDICTOR as follows:

  List, Johann-Mattis and van Dam, Kellen Parker (2024): EDICTOR 3. A web-based tool for computer-assisted language comparison [Software Tool, Version 3.0]. MCL Chair at the University of Passau: Passau. URL: https://edictor.org/.

Data has not yet been saved.